"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.run = void 0;
const utils_package_1 = require("@goldstack/utils-package");
const utils_cli_1 = require("@goldstack/utils-cli");
const utils_terraform_1 = require("@goldstack/utils-terraform");
const utils_terraform_aws_1 = require("@goldstack/utils-terraform-aws");
const utils_package_config_1 = require("@goldstack/utils-package-config");
const utils_package_2 = require("@goldstack/utils-package");
const yargs_1 = __importDefault(require("yargs"));
const fs_1 = __importDefault(require("fs"));
const utils_aws_lambda_1 = require("@goldstack/utils-aws-lambda");
const templateLambdaConsts_1 = require("./templateLambdaConsts");
const utils_sh_1 = require("@goldstack/utils-sh");
const run = async (args) => {
    await (0, utils_cli_1.wrapCli)(async () => {
        const argv = await (0, utils_package_1.buildCli)({
            yargs: yargs_1.default,
            deployCommands: (0, utils_package_1.buildDeployCommands)(),
            infraCommands: (0, utils_terraform_1.infraCommands)(),
        })
            .command('build [deployment]', 'Build all lambdas', () => {
            return yargs_1.default.positional('deployment', {
                type: 'string',
                describe: 'Name of the deployment this command should be applied to',
                default: '',
            });
        })
            .help()
            .parse();
        const packageConfig = new utils_package_config_1.PackageConfig({
            packagePath: './',
        });
        const config = packageConfig.getConfig();
        // update routes
        if (!fs_1.default.existsSync(templateLambdaConsts_1.defaultRoutesPath)) {
            throw new Error(`Please specify lambda function handlers in ${templateLambdaConsts_1.defaultRoutesPath} so that API Gateway route configuration can be generated.`);
        }
        const lambdaRoutes = (0, utils_aws_lambda_1.readLambdaConfig)(templateLambdaConsts_1.defaultRoutesPath);
        config.deployments = config.deployments.map((e) => {
            const lambdasConfigs = (0, utils_aws_lambda_1.generateLambdaConfig)(e.configuration, lambdaRoutes);
            e.configuration.lambdas = lambdasConfigs;
            (0, utils_aws_lambda_1.validateDeployment)(e.configuration.lambdas);
            return e;
        });
        (0, utils_package_2.writePackageConfig)(config);
        const command = argv._[0];
        const [, , , ...opArgs] = args;
        if (command === 'infra') {
            await (0, utils_terraform_aws_1.terraformAwsCli)(opArgs, {
                // temporary workaround for https://github.com/goldstack/goldstack/issues/40
                parallelism: 1,
            });
            return;
        }
        if (command === 'build') {
            const deployment = packageConfig.getDeployment(opArgs[0]);
            await (0, utils_aws_lambda_1.buildFunctions)({
                routesDir: templateLambdaConsts_1.defaultRoutesPath,
                buildOptions: (0, utils_aws_lambda_1.defaultBuildOptions)(),
                deploymentName: deployment.name,
                configs: lambdaRoutes,
                lambdaNamePrefix: deployment.configuration.lambdaNamePrefix || '',
                packageRootDir: (0, utils_sh_1.pwd)(),
            });
            return;
        }
        if (command === 'deploy') {
            await (0, utils_aws_lambda_1.deployFunctions)({
                routesPath: templateLambdaConsts_1.defaultRoutesPath,
                configuration: packageConfig.getDeployment(opArgs[0]).configuration,
                deployment: packageConfig.getDeployment(opArgs[0]),
                config: lambdaRoutes,
                packageRootFolder: (0, utils_sh_1.pwd)(),
            });
            return;
        }
        throw new Error('Unknown command: ' + command);
    });
};
exports.run = run;
//# sourceMappingURL=templateLambdaApiCli.js.map